abacusai.streaming_connector — AbacusAI documentation

# `abacusai.streaming_connector`

## Module Contents

### Classes

`StreamingConnector` | A connector to an external service

class abacusai.streaming_connector.StreamingConnector(client, streamingConnectorId=None, service=None, name=None, createdAt=None, status=None, auth=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A connector to an external service

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - streamingConnectorId (str) – The unique ID for the connection.

    - service (str) – The service this connection connects to

    - name (str) – A user-friendly name for the service

    - createdAt (str) – When the API key was created

    - status (str) – The status of the Database Connector

    - auth (dict) –

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict

  verify()

    Checks to see if Abacus.AI can access the streaming connector.

    Parameters

      streaming_connector_id (str) – The unique identifier for the streaming connector.

  rename(name)

    Renames a Streaming Connector

    Parameters

      name (str) – A new name for the streaming connector

  delete()

    Delete a streaming connector.

    Parameters

      streaming_connector_id (str) – The unique identifier for the streaming connector.